<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>ActionWindow</name>
    <message>
        <source>Running postinstall</source>
        <translation>安装后运行</translation>
    </message>
    <message>
        <source>Directory %1 already exists, perhaps from the previous installation.&lt;br /&gt;Do you want to delete it and continue installation?</source>
        <translation>目录 %1 已存在, 或许来自以前的安装.&lt;br /&gt;需要删除并且继续安装吗?</translation>
    </message>
    <message>
        <source>Installing game .... from file .....</source>
        <translation>安装游戏 .... 来自文件 .....</translation>
    </message>
    <message>
        <source>Directory %1 already exists.&lt;br /&gt;Please, delete it manually and repeat an installation.</source>
        <translation>目录 %1 已存在.&lt;br /&gt;请手动删除并且重新安装.</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Installation Steps:</source>
        <translation>安装步骤:</translation>
    </message>
    <message>
        <source>Install Game</source>
        <translation>安装游戏</translation>
    </message>
    <message>
        <source>Warning: </source>
        <translation>警告:</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>进程</translation>
    </message>
    <message>
        <source>Step %1</source>
        <translation>步骤 %1</translation>
    </message>
    <message>
        <source>Abort installation?</source>
        <translation>中止安装?</translation>
    </message>
    <message>
        <source>Remove dir?</source>
        <translation>删除目录?</translation>
    </message>
    <message>
        <source>Failed!</source>
        <translation>失败!</translation>
    </message>
    <message>
        <source>Updating status</source>
        <translation>更新状态</translation>
    </message>
    <message>
        <source>Postinstall script failed!&lt;br /&gt;Please, check the output:&lt;br /&gt;</source>
        <translation>安装脚本失败&lt;br /&gt;请检查输行:&lt;br /&gt;</translation>
    </message>
    <message>
        <source>Are you sure you want to abort installation?</source>
        <translation>确定要中止安装?</translation>
    </message>
</context>
<context>
    <name>FindIpkWindow</name>
    <message>
        <source>Done</source>
        <translation type="obsolete">完成</translation>
    </message>
    <message>
        <source>You have to download original game file with name </source>
        <translation type="obsolete">需要下载原本游戏文件 </translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:18pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:22pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Locate .IPK file in different folder...</source>
        <translation>在不同目录中定位 .IPK文件...</translation>
    </message>
    <message>
        <source>If you&apos;re sure that you downloaded right .ipk file to MyDocs/Downloads directory, then click &quot;Done&quot;</source>
        <translation type="obsolete">确定下载正确的 .IPK文件到 MyDocs/Download 目录, 然后点击&quot;完成&quot;</translation>
    </message>
    <message>
        <source>Open Game Website</source>
        <translation type="obsolete">打开游戏主页</translation>
    </message>
    <message>
        <source>IPK (*.ipk)</source>
        <translation>IPK (*.ipk)</translation>
    </message>
    <message>
        <source>Find IPK file...</source>
        <translation>搜索 IPK 文件...</translation>
    </message>
    <message>
        <source>Locate IPK File</source>
        <translation>定位 IPK文件</translation>
    </message>
    <message>
        <source> and save it into the/Downloads folder.</source>
        <translation type="obsolete">并且保存到 /Downloads 文件夹.</translation>
    </message>
    <message>
        <source>Manager can&apos;t find file &lt;b&gt;%1&lt;/b&gt; in &lt;b&gt;MyDocs/Downloads&lt;/b&gt; folder. Download it into this folder or locate in the different folder.&lt;br /&gt;&lt;font color=&quot;red&quot;&gt;Note, that there is &lt;b&gt;NO OFFICIAL WAY&lt;/b&gt; to buy PalmPre games. The only possible way is to search google and download it by yourself.&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InstallWindow</name>
    <message>
        <source> by </source>
        <translation> 由 </translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>注释</translation>
    </message>
    <message>
        <source>Can&apos;t create directory %1</source>
        <translation>无法创建目录 %1</translation>
    </message>
    <message>
        <source>Extracting game info</source>
        <translation>提取游戏信息</translation>
    </message>
    <message>
        <source>Prepare desktop shortcut</source>
        <translation>准备桌面快捷方式</translation>
    </message>
    <message>
        <source>Unpack archive (it may take a while)</source>
        <translation>解压文件包(需要一些时间)</translation>
    </message>
    <message>
        <source>Cannot create .desktop file </source>
        <translation>无法创建 .desktop 文件 </translation>
    </message>
    <message>
        <source>Cannot unpack archive:&lt;br /&gt;</source>
        <translation>无法解压文件包:&lt;br /&gt;</translation>
    </message>
    <message>
        <source>Available free space in /home/user/MyDocs directory is %1MB, but the game requires %2MB!</source>
        <translation> /home/user/MyDocs 目录的可用空间为 %1MB, 但是游戏需要 %2MB!</translation>
    </message>
    <message>
        <source>Install game</source>
        <translation>安装游戏</translation>
    </message>
    <message>
        <source>Prepare files and symlinks</source>
        <translation>准备文件和链接</translation>
    </message>
    <message>
        <source>Game installed!</source>
        <translation>游戏安装!</translation>
    </message>
    <message>
        <source>Cannot parse JSON: </source>
        <translation>无法解析JSON: </translation>
    </message>
    <message>
        <source>Seems to be wrong game or naming error!&lt;br /&gt;Ipk ID: %1&lt;br /&gt;Expected ID mask: %2</source>
        <translation>似乎是错误的游戏或命名错误!&lt;br /&gt;&gt;Ipk ID: %1&lt;br /&gt;预期掩码ID: %2</translation>
    </message>
    <message>
        <source>Prepare directories</source>
        <translation>准备目录</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>安装</translation>
    </message>
    <message>
        <source>Error parsing appinfo.json!</source>
        <translation>appinfo.json 解析错误!</translation>
    </message>
    <message>
        <source>Cannot create DBUS .service file </source>
        <translation>无法创建 DBUS .service 文件 </translation>
    </message>
    <message>
        <source>Checking available space</source>
        <translation>检查可用空间</translation>
    </message>
    <message>
        <source>Cannot copy icon </source>
        <translation>无法复制图标 </translation>
    </message>
    <message>
        <source>Main property not found in Json: </source>
        <translation>在.json中无法找到主要特性: </translation>
    </message>
    <message>
        <source>Cannot copy binary file </source>
        <translation>无法复制二进制文件</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>无法创建目录 %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Saves</source>
        <translation>存档</translation>
    </message>
    <message>
        <source>Install</source>
        <translation>安装</translation>
    </message>
    <message>
        <source>Manage Saves</source>
        <translation>管理存档</translation>
    </message>
    <message>
        <source>WebOS Games</source>
        <translation>WebOS Games</translation>
    </message>
    <message numerus="yes">
        <source>%n games supported</source>
        <translation>
            <numerusform>%n 已支持</numerusform>
        </translation>
    </message>
    <message>
        <source>Install/Uninstall</source>
        <translation>安装/卸载</translation>
    </message>
    <message numerus="yes">
        <source>, %n games installed</source>
        <translation>
            <numerusform>, %n 已安装</numerusform>
        </translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; color:#1f45d0;&quot;&gt;Games Info&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ManageWindow</name>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Install</source>
        <translation>安装</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
    <message>
        <source>Game installed</source>
        <translation>游戏安装</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1?&lt;br /&gt;You might want to backup your saves first.</source>
        <translation>确定要卸载 %1?&lt;br /&gt;建议首先备份存档.</translation>
    </message>
    <message>
        <source>Found!</source>
        <translation>找到!</translation>
    </message>
    <message>
        <source>IPK file</source>
        <translation>IPK 文件</translation>
    </message>
    <message>
        <source>Not Found</source>
        <translation>无法找到</translation>
    </message>
    <message>
        <source>Find IPK file...</source>
        <translation>搜索IPK文件...</translation>
    </message>
    <message>
        <source>Space Required</source>
        <translation>所需空间</translation>
    </message>
    <message>
        <source>Refresh List</source>
        <translation>刷新列表</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>IPK File:</source>
        <translation>IPK文件:</translation>
    </message>
    <message>
        <source>Install Games</source>
        <translation>安装游戏</translation>
    </message>
    <message>
        <source>Uninstall game?</source>
        <translation>卸载游戏?</translation>
    </message>
    <message>
        <source> (version %1)</source>
        <translation> (版本 %1)</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>开始</translation>
    </message>
</context>
<context>
    <name>SavesListDelegate</name>
    <message>
        <source>Never</source>
        <translation>从不</translation>
    </message>
    <message>
        <source>Last backup: </source>
        <translation>最后备份: </translation>
    </message>
</context>
<context>
    <name>SavesWindow</name>
    <message>
        <source>Done!</source>
        <translation>完成!</translation>
    </message>
    <message>
        <source>Can&apos;t find the file %1&lt;br /&gt;Backup was created, butprobably file was deleted manually.</source>
        <translation>无法找到文件 %1&lt;br /&gt;备份已创建,但可能文件被手动删除.</translation>
    </message>
    <message>
        <source>Manage Saves</source>
        <translation>管理存档</translation>
    </message>
    <message>
        <source>Backup All</source>
        <translation>备份全部</translation>
    </message>
    <message>
        <source>Can&apos;t find the directory %1&lt;br /&gt;Backup was created, butprobably deleted manually.</source>
        <translation>无法找到目录 %1&lt;br /&gt;备份已创建,但可能被手动删除.</translation>
    </message>
    <message>
        <source>Backup</source>
        <translation>备份</translation>
    </message>
    <message>
        <source>Games information restored</source>
        <translation>游戏信息恢复</translation>
    </message>
    <message>
        <source>Can&apos;t create dir %1</source>
        <translation>无法创建目录 %1</translation>
    </message>
    <message>
        <source>Game information is saved</source>
        <translation>游戏信息已保存</translation>
    </message>
    <message>
        <source>Restore All</source>
        <translation>恢复所有</translation>
    </message>
    <message>
        <source>Can&apos;t copy file %1 to %2&lt;br /&gt;Backup was created, butprobably file was deleted manually.</source>
        <translation>无法复制文件 %1 到 %2&lt;br /&gt;备份已创建,但可能文件被手动删除.</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>恢复</translation>
    </message>
    <message>
        <source>Games information backed up</source>
        <translation>游戏信息备份</translation>
    </message>
    <message>
        <source>Can&apos;t copy file %1 to %2</source>
        <translation>无法复制文件 %1 到 %2</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Game information restored</source>
        <translation>游戏信息恢复</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Binary Directory</source>
        <translation>二进制目录</translation>
    </message>
    <message>
        <source>Downloads Directory</source>
        <translation>下载目录</translation>
    </message>
    <message>
        <source>Saves Directory</source>
        <translation>存档目录</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Data Dir</source>
        <translation>数据目录</translation>
    </message>
    <message>
        <source>Bin Dir</source>
        <translation>存储目录</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Saves Dir</source>
        <translation>存档目录</translation>
    </message>
    <message>
        <source>Downloads Dir</source>
        <translation>下载目录</translation>
    </message>
    <message>
        <source>Game Data Directory</source>
        <translation>游戏数据目录</translation>
    </message>
</context>
<context>
    <name>TrackerCfg</name>
    <message>
        <source>Tracker Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The tracker configuration must be changed to avoid messing up media cache with media from the games&apos; folders.&lt;br /&gt;The tracker also need to restart and rebuild databases.&lt;br /&gt;&lt;br /&gt;Do you want to change config and restart tracker now?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UninstallWindow</name>
    <message>
        <source>Cannot delete file %1</source>
        <translation>无法删除文件 %1</translation>
    </message>
    <message>
        <source>Data directory %1 does not exist.&lt;br /&gt;This means some manual intervention or the program bug.</source>
        <translation>数据目录 %1 不存在.&lt;br /&gt;可能需要人为干预或程序错误.</translation>
    </message>
    <message>
        <source>Cannot delete dir %1</source>
        <translation>无法删除目录 %1</translation>
    </message>
    <message>
        <source>Cleaning up</source>
        <translation>清理</translation>
    </message>
    <message>
        <source>Uninstall game</source>
        <translation>卸载游戏</translation>
    </message>
    <message>
        <source>Game Title is not found. That means some manual edit or program bug.</source>
        <translation>无法找到游戏名称.可能需要手动编辑或程序错误.</translation>
    </message>
    <message>
        <source>Game uninstalled successfully!</source>
        <translation>游戏卸载完成!</translation>
    </message>
    <message>
        <source>Removing game</source>
        <translation>删除游戏</translation>
    </message>
    <message>
        <source>Bin directory %1 does not exist.&lt;br /&gt;This means some manual intervention or the program bug.</source>
        <translation>存储目录 %1 不存在.&lt;br /&gt;可能需要人为干预或程序错误.</translation>
    </message>
    <message>
        <source>Checking directories</source>
        <translation>检查目录</translation>
    </message>
    <message>
        <source>Uninstalling</source>
        <translation>卸载</translation>
    </message>
</context>
</TS>
